@@ -27,8 +27,9 @@ def is_name_valid(app_name):
 #get all arguments passed
 def get_args():
   args = sys.argv
-  print(args.index(0))
-  print(args.index(1))
+  print(args)
+  args.remove(0)
+  print(args)
   return args
 
 def is_args_valid(args):
